======
orsopy
======

.. image:: https://img.shields.io/pypi/v/orsopy.svg
        :target: https://pypi.python.org/pypi/orsopy

.. image:: https://github.com/reflectivity/orsopy/actions/workflows/pytest.yml/badge.svg
        :target: https://github.com/reflectivity/orsopy/actions/workflows/pytest.yml

.. image:: https://readthedocs.org/projects/orsopy/badge/?version=latest
        :target: https://orsopy.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status



orsopy is a Python implementation of ORSO functionality, this includes `reduced data file formats`_.


* Free software: TDB
* Documentation: https://orsopy.readthedocs.io.


Features
--------

* TODO

.. _`reduced data file formats`: https://www.reflectometry.org/working_groups/file_formats/
